@@ -23,7 +23,7 @@ def _ping_nano():
     return b"NanoVib" in subprocess.check_output("netsh wlan show interfaces", shell=True)
 
 
-def _get_most_recent_measurement(folder_to_analyze: Path = (Path() / "Downloads")) -> Path:
+def _get_most_recent_measurement(folder_to_analyze: Path = (Path().home() / "Downloads")) -> Path:
     most_recent_measurement = folder_to_analyze / "CON" / "00010101_000000_combined.txt"
     for p0 in folder_to_analyze.iterdir():
         if not p0.is_dir():
@@ -43,7 +43,7 @@ def _get_most_recent_measurement(folder_to_analyze: Path = (Path() / "Downloads"
     return most_recent_measurement
 
 
-def continuous_analyzing(folder_to_analyze: Path = (Path() / "Downloads")) -> None:
+def continuous_analyzing(folder_to_analyze: Path = (Path().home() / "Downloads")) -> None:
     tnow = 10 * int(time.time() // 10)
     delta = 1
     last_analyzing = [folder_to_analyze / "CON" / "00010101_000000_combined.txt", 0]
